| | |
|---|---|
| Tests | [![Test](https://github.com/fptiangco/stringtoolsfpat/actions/workflows/test_uploadpypi.yaml/badge.svg)](https://github.com/fptiangco/stringtoolsfpat/actions/workflows/test_uploadpypi.yaml) [![codecov](https://codecov.io/gh/fptiangco/stringtoolsfpat/branch/main/graph/badge.svg?token=EQSINEBTEU)](https://codecov.io/gh/fptiangco/stringtoolsfpat) |
| Pypi | [![PyPI version](https://badge.fury.io/py/stringtoolsfpat.svg)](https://badge.fury.io/py/stringtoolsfpat) ![PyPI - Downloads](https://img.shields.io/pypi/dm/stringtoolsfpat) ![PyPI - Format](https://img.shields.io/pypi/format/stringtoolsfpat) |
| Code | [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) |
|Scan | [![Updates](https://pyup.io/repos/github/fptiangco/stringtoolsfpat/shield.svg)](https://pyup.io/repos/github/fptiangco/stringtoolsfpat/) |
| Docs | [![Read the Docs](https://readthedocs.org/projects/stringtoolsfpat/badge/?version=latest)](https://stringtoolsfpat.readthedocs.io/en/latest/) |



### Summary
Lorem Ipsum
